PluginManager/PluginRepositoryDialog.py

changeset 15
f6ccc31d6e72
parent 13
1af94a91f439
child 45
9a18f4dbb493
diff -r 092aa8fafa4e -r f6ccc31d6e72 PluginManager/PluginRepositoryDialog.py
--- a/PluginManager/PluginRepositoryDialog.py	Sat Jan 02 16:15:57 2010 +0000
+++ b/PluginManager/PluginRepositoryDialog.py	Sat Jan 02 17:09:08 2010 +0000
@@ -31,7 +31,7 @@
 
 import UI.PixmapCache
 
-from eric4config import getConfig
+from eric5config import getConfig
 
 descrRole    = Qt.UserRole
 urlRole      = Qt.UserRole + 1
@@ -626,10 +626,10 @@
     
     def __startPluginInstall(self):
         """
         Private slot to start the eric4 plugin installation dialog.
         """
         proc = QProcess()
-        applPath = os.path.join(getConfig("ericDir"), "eric4-plugininstall.py")
+        applPath = os.path.join(getConfig("ericDir"), "eric5-plugininstall.py")
         
         args = []
         args.append(applPath)
@@ -644,4 +644,4 @@
                 ).format(applPath),
                 self.trUtf8('OK'))
         
-        self.close()
+        self.close()
\ No newline at end of file
@@ -626,10 +626,10 @@
     def __startPluginInstall(self):
         """
-        Private slot to start the eric4 plugin installation dialog.
+        Private slot to start the eric5 plugin installation dialog.
         """
         proc = QProcess()

eric ide

mercurial